.. image:: https://dev.azure.com/spacetelescope/tweakwcs/_apis/build/status/spacetelescope.tweakwcs?branchName=master
    :target: https://dev.azure.com/spacetelescope/tweakwcs/_build/latest?definitionId=5&branchName=master
    :alt: Azure Pipelines build status

.. image:: https://codecov.io/gh/spacetelescope/tweakwcs/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/spacetelescope/tweakwcs
  :alt: Test coverage status

.. image:: https://readthedocs.org/projects/tweakwcs/badge/?version=latest
    :target: https://tweakwcs.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

``tweakwcs`` is a package that provides core algorithms for computing and
applying corrections to ``WCS`` objects such as to minimize mismatch between
image and reference catalogs. Currently only aligning images with ``FITS WCS``
and ``JWST gWCS`` are supported.
